This is a CalDAV and CardDAV front-end for `EteSync <https://www.etesync.com>`_.

This package provides a local CalDAV and CardDAV server that proxies requests
to an EteSync server for use with desktop CalDAV and CardDAV clients.

This is essentially a compatibility layer between EteSync and DAV clients.

| Source code: https://github.com/etesync/etesync-dav
| README: https://github.com/etesync/etesync-dav/blob/master/README.md
